==> owncloud-app-bookmarks-9.0.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/bookmarks/l10n/sq.php <==
<?php
$TRANSLATIONS = array(
"Bookmarks" => "Faqerojtës",
"Bookm." => "Faqer.",
"No file provided for import" => "S’u dha kartelë për importim",
"Unsupported file type for import" => "Lloj i pambuluar kartele për importim",
"Some Error happened." => "Ndodhi i njëjti Gabim.",
"Error" => "Gabim",
"Tags" => "Etiketa",
"Filter by tag" => "Filtroji sipas etiketash",
"Are you sure you want to remove this bookmark?" => "Jeni i sigurt se doni të hiqet ky faqerojtës?",
"Warning" => "Kujdes",
"Are you sure you want to remove this tag from every entry?" => "Jeni i sigurt se doni të hiqet kjo etiketë nga çdo zë?",
"Import error" => "Gabim importimi",
"Import completed successfully." => "Importimi u plotësua me sukses.",
"Uploading..." => "Po ngarkohet...",
"Add a bookmark" => "Shtoni faqerojtës",
"This URL is already bookmarked! Overwrite?" => "Kjo URL është faqeruajtur tashmë! Të mbishkruhet?",
"The title of the page" => "Titulli i faqes",
"The address of the page" => "Adresa e faqes",
"Description of the page" => "Përshkrim i faqes",
"Save" => "Ruaje",
"Delete" => "Fshije",
"Edit" => "Përpunojeni",
"Cancel" => "Anuloje",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Tërhiqeni këtë te faqerojtësit e shfletuesit tuaj dhe klikojeni kur doni të faqeruani shpejt e shpejt një faqe:",
"Add to ownCloud" => "Shtoje te ownCloud",
"Address" => "Adresë",
"Filterable Tags" => "Etiketa të Filtrueshme",
"You have no bookmarks" => "S’keni faqerojtës",
"You can also import a bookmark file" => "Mundeni edhe të importoni një kartelë faqerojtësish",
"Export & Import" => "Imporoni & Eksportoni",
"Export" => "Eksporto",
"Import" => "Importo"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud-app-bookmarks-9.1.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/bookmarks/l10n/sq.php <==
<?php
$TRANSLATIONS = array(
"Bookmarks" => "Faqerojtës",
"Bookm." => "Faqer.",
"No file provided for import" => "S’u dha kartelë për importim",
"Unsupported file type for import" => "Lloj i pambuluar kartele për importim",
"Some Error happened." => "Ndodhi i njëjti Gabim.",
"Error" => "Gabim",
"Tags" => "Etiketa",
"Filter by tag" => "Filtroji sipas etiketash",
"Are you sure you want to remove this bookmark?" => "Jeni i sigurt se doni të hiqet ky faqerojtës?",
"Warning" => "Kujdes",
"Are you sure you want to remove this tag from every entry?" => "Jeni i sigurt se doni të hiqet kjo etiketë nga çdo zë?",
"Import error" => "Gabim importimi",
"Import completed successfully." => "Importimi u plotësua me sukses.",
"Uploading..." => "Po ngarkohet...",
"Add a bookmark" => "Shtoni faqerojtës",
"This URL is already bookmarked! Overwrite?" => "Kjo URL është faqeruajtur tashmë! Të mbishkruhet?",
"The title of the page" => "Titulli i faqes",
"The address of the page" => "Adresa e faqes",
"Description of the page" => "Përshkrim i faqes",
"Save" => "Ruaje",
"Delete" => "Fshije",
"Edit" => "Përpunojeni",
"Cancel" => "Anuloje",
"Drag this to your browser bookmarks and click it, when you want to bookmark a webpage quickly:" => "Tërhiqeni këtë te faqerojtësit e shfletuesit tuaj dhe klikojeni kur doni të faqeruani shpejt e shpejt një faqe:",
"Add to ownCloud" => "Shtoje te ownCloud",
"Address" => "Adresë",
"Filterable Tags" => "Etiketa të Filtrueshme",
"You have no bookmarks" => "S’keni faqerojtës",
"You can also import a bookmark file" => "Mundeni edhe të importoni një kartelë faqerojtësish",
"Bookmarklet" => "Përmbajtës faqerojtësish",
"Export & Import" => "Importoni & Eksportoni",
"Export" => "Eksporto",
"Import" => "Importo"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
